#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_XOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_XOR_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/bitwise_xor.hpp>

#endif
